@@ -1,6 +1,6 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
-# Copyright 2015 Earth Sciences Department, BSC-CNS
+# Copyright 2015-2020 Earth Sciences Department, BSC-CNS
 
 # This file is part of Autosubmit.
 
@@ -22,13 +22,14 @@ Module containing functions to manage autosubmit's database.
 """
 import os
 import sqlite3
-import string
-
-from autosubmit.config.log import Log
-from autosubmit.config.basicConfig import BasicConfig
+import multiprocessing
+import autosubmit
+from log.log import Log, AutosubmitCritical, AutosubmitError
+Log.get_logger("Autosubmit")
+from autosubmitconfigparser.config.basicconfig import BasicConfig
 
 CURRENT_DATABASE_VERSION = 1
-
+TIMEOUT = 10
 
 def create_db(qry):
     """
@@ -40,329 +41,21 @@ def create_db(qry):
     try:
         (conn, cursor) = open_conn(False)
     except DbException as e:
-        Log.error('Connection to database could not be established: {0}', e.message)
-        return False
+        raise AutosubmitCritical(
+            "Could not establish a connection to database", 7001, str(e))
 
     try:
         cursor.executescript(qry)
-    except sqlite3.Error:
+    except sqlite3.Error as e:
         close_conn(conn, cursor)
-        Log.error('The database can not be created.' + 'DB file:' + BasicConfig.DB_PATH)
-        return False
+        raise AutosubmitCritical(
+            'Database can not be created', 7004, str(e))
 
     conn.commit()
     close_conn(conn, cursor)
     return True
 
 
-def _set_experiment(name, description, version):
-    """
-    Stores experiment in database
-
-    :param name: experiment's name
-    :type name: str
-    :param description: experiment's description
-    :type description: str
-    """
-    if not check_db():
-        return False
-    name = check_name(name)
-    if name == '':
-        return False
-    try:
-        (conn, cursor) = open_conn()
-    except DbException as e:
-        Log.error('Connection to database could not be established: {0}', e.message)
-        return False
-    try:
-        cursor.execute('INSERT INTO experiment (name, description, autosubmit_version) VALUES (:name, :description, '
-                       ':version)',
-                       {'name': name, 'description': description, 'version': version})
-    except sqlite3.IntegrityError as e:
-        close_conn(conn, cursor)
-        Log.error('Could not register experiment: {0}'.format(e))
-        return False
-
-    conn.commit()
-    close_conn(conn, cursor)
-    return True
-
-
-def check_experiment_exists(name, error_on_inexistence=True):
-    """
-    Checks if exist an experiment with the given name.
-
-    :param error_on_inexistence: if True, adds an error log if experiment does not exists
-    :type error_on_inexistence: bool
-    :param name: Experiment name
-    :type name: str
-    :return: If experiment exists returns true, if not returns false
-    :rtype: bool
-    """
-    if not check_db():
-        return False
-    name = check_name(name)
-    if name == '':
-        return False
-
-    try:
-        (conn, cursor) = open_conn()
-    except DbException as e:
-        Log.error('Connection to database could not be established: {0}', e.message)
-        return False
-    conn.isolation_level = None
-
-    # SQLite always return a unicode object, but we can change this
-    # behaviour with the next sentence
-    conn.text_factory = str
-    cursor.execute('select name from experiment where name=:name', {'name': name})
-    row = cursor.fetchone()
-    close_conn(conn, cursor)
-    if row is None:
-        if error_on_inexistence:
-            Log.error('The experiment name "{0}" does not exist yet!!!', name)
-        return False
-    return True
-
-
-def get_autosubmit_version(expid):
-    """
-    Get the minimun autosubmit version needed for the experiment
-
-    :param expid: Experiment name
-    :type expid: str
-    :return: If experiment exists returns the autosubmit version for it, if not returns None
-    :rtype: str
-    """
-    if not check_db():
-        return False
-
-    try:
-        (conn, cursor) = open_conn()
-    except DbException as e:
-        Log.error('Connection to database could not be established: {0}', e.message)
-        return False
-    conn.isolation_level = None
-
-    # SQLite always return a unicode object, but we can change this
-    # behaviour with the next sentence
-    conn.text_factory = str
-    cursor.execute('SELECT autosubmit_version FROM experiment WHERE name=:expid', {'expid': expid})
-    row = cursor.fetchone()
-    close_conn(conn, cursor)
-    if row is None:
-        Log.error('The experiment "{0}" does not exist yet!!!', expid)
-        return None
-    return row[0]
-
-
-def new_experiment(description, version, test=False):
-    """
-    Stores a new experiment on the database and generates its identifier
-
-    :param version: autosubmit version associated to the experiment
-    :type version: str
-    :param test: flag for test experiments
-    :type test: bool
-    :param description: experiment's description
-    :type description: str
-    :return: experiment id for the new experiment
-    :rtype: str
-    """
-    if test:
-        last_exp_name = last_name_used(True)
-    else:
-        last_exp_name = last_name_used()
-    if last_exp_name == '':
-        return ''
-    if last_exp_name == 'empty':
-        if test:
-            # test identifier restricted also to 4 characters.
-            new_name = 't000'
-        else:
-            new_name = 'a000'
-    else:
-        new_name = _next_name(last_exp_name)
-        if new_name == '':
-            return ''
-    while check_experiment_exists(new_name, False):
-        new_name = _next_name(new_name)
-        if new_name == '':
-            return ''
-    if not _set_experiment(new_name, description, version):
-        return ''
-    Log.info('The new experiment "{0}" has been registered.', new_name)
-    return new_name
-
-
-def copy_experiment(name, description, version, test=False):
-    """
-    Creates a new experiment by copying an existing experiment
-
-    :param test: specifies if it is a test experiment
-    :type test: bool
-    :param version: experiment's associated autosubmit version
-    :type version: str
-    :param name: identifier of experiment to copy
-    :type name: str
-    :param description: experiment's description
-    :type description: str
-    :return: experiment id for the new experiment
-    :rtype: str
-    """
-    if not check_experiment_exists(name):
-        return ''
-    new_name = new_experiment(description, version, test)
-    return new_name
-
-
-def base36encode(number, alphabet=string.digits + string.ascii_lowercase):
-    """
-    Convert positive integer to a base36 string.
-
-    :param number: number to convert
-    :type number: int
-    :param alphabet: set of characters to use
-    :type alphabet: str
-    :return: number's base36 string value
-    :rtype: str
-    """
-    if not isinstance(number, (int, long)):
-        raise TypeError('number must be an integer')
-
-    # Special case for zero
-    if number == 0:
-        return '0'
-
-    base36 = ''
-
-    sign = ''
-    if number < 0:
-        sign = '-'
-        number = - number
-
-    while number > 0:
-        number, i = divmod(number, len(alphabet))
-        # noinspection PyAugmentAssignment
-        base36 = alphabet[i] + base36
-
-    return sign + base36.rjust(4, '0')
-
-
-def base36decode(number):
-    """
-    Converts a base36 string to a positive integer
-
-    :param number: base36 string to convert
-    :type number: str
-    :return: number's integer value
-    :rtype: int
-    """
-    return int(number, 36)
-
-
-def _next_name(name):
-    """
-    Get next experiment identifier
-
-    :param name: previous experiment identifier
-    :type name: str
-    :return: new experiment identifier
-    :rtype: str
-    """
-    name = check_name(name)
-    if name == '':
-        return ''
-    # Convert the name to base 36 in number add 1 and then encode it
-    return base36encode(base36decode(name) + 1)
-
-
-def last_name_used(test=False):
-    """
-    Gets last experiment identifier used
-
-    :param test: flag for test experiments
-    :type test: bool
-    :return: last experiment identifier used, 'empty' if there is none
-    :rtype: str
-    """
-    if not check_db():
-        return ''
-    try:
-        (conn, cursor) = open_conn()
-    except DbException as e:
-        Log.error('Connection to database could not be established: {0}', e.message)
-        return ''
-    conn.text_factory = str
-    if test:
-        cursor.execute('SELECT name '
-                       'FROM experiment '
-                       'WHERE rowid=(SELECT max(rowid) FROM experiment WHERE name LIKE "t%" AND '
-                       'autosubmit_version IS NOT NULL AND '
-                       'NOT (autosubmit_version LIKE "%3.0.0b%"))')
-    else:
-        cursor.execute('SELECT name '
-                       'FROM experiment '
-                       'WHERE rowid=(SELECT max(rowid) FROM experiment WHERE name NOT LIKE "t%" AND '
-                       'autosubmit_version IS NOT NULL AND '
-                       'NOT (autosubmit_version LIKE "%3.0.0b%"))')
-    row = cursor.fetchone()
-    close_conn(conn, cursor)
-    if row is None:
-        return 'empty'
-
-    # If starts by number (during 3.0 beta some jobs starting with numbers where created), returns empty.
-    try:
-        int(row[0][0])
-        return 'empty'
-    except ValueError:
-        return row[0]
-
-
-def delete_experiment(name):
-    """
-    Removes experiment from database
-
-    :param name: experiment identifier
-    :type name: str
-    :return: True if delete is succesful
-    :rtype: bool
-    """
-    if not check_db():
-        return False
-    name = check_name(name)
-    if name == '':
-        return False
-    try:
-        (conn, cursor) = open_conn()
-    except DbException as e:
-        Log.error('Connection to database could not be established: {0}', e.message)
-        return False
-    cursor.execute('DELETE FROM experiment '
-                   'WHERE name=:name', {'name': name})
-    row = cursor.fetchone()
-    if row is None:
-        Log.debug('The experiment {0} has been deleted!!!', name)
-    close_conn(conn, cursor)
-    return True
-
-
-def check_name(name):
-    """
-    Checks if it is a valid experiment identifier
-
-    :param name: experiment identifier to check
-    :type name: str
-    :return: name if is valid, terminates program otherwise
-    :rtype: str
-    """
-    name = name.lower()
-    if len(name) < 4 or not name.isalnum():
-        Log.error("So sorry, but the name must have at least 4 alphanumeric chars!!!")
-        return ''
-    return name
-
-
 def check_db():
     """
     Checks if database file exist
@@ -371,8 +64,8 @@ def check_db():
     """
 
     if not os.path.exists(BasicConfig.DB_PATH):
-        Log.error('Some problem has happened...check the database file.' + 'DB file:' + BasicConfig.DB_PATH)
-        return False
+        raise AutosubmitCritical(
+            'DB path does not exists: {0}'.format(BasicConfig.DB_PATH), 7003)
     return True
 
 
@@ -410,14 +103,13 @@ def open_conn(check_version=True):
         # If database version is not the expected, update database....
         if version < CURRENT_DATABASE_VERSION:
             if not _update_database(version, cursor):
-                raise DbException('Database version could not be updated')
+                raise AutosubmitCritical(
+                    'Database version doesn''t match', 7001)
 
         # ... or ask for autosubmit upgrade
         elif version > CURRENT_DATABASE_VERSION:
-            Log.critical('Database version is not compatible with this autosubmit version. Please execute pip install '
-                         'autosubmit --upgrade')
-            raise DbException('Database version not compatible')
-
+            raise AutosubmitCritical('Database version is not compatible with this autosubmit version. Please execute pip install '
+                                     'autosubmit --upgrade', 7002)
     return conn, cursor
 
 
@@ -435,9 +127,411 @@ def close_conn(conn, cursor):
     conn.close()
     return
 
+def fn_wrapper(database_fn, queue, *args):
+    # TODO: We can also implement the anti-lock mechanism as function decorators in a next iteration.
+    result = database_fn(*args)
+    queue.put(result)
+    queue.close()
+
+def save_experiment(name, description, version):
+    """
+    Stores experiment in database. Anti-lock version.  
+
+    :param version:
+    :type version: str
+    :param name: experiment's name
+    :type name: str
+    :param description: experiment's description
+    :type description: str    
+    """
+    queue = multiprocessing.Queue(1)
+    proc = multiprocessing.Process(target=fn_wrapper, args=(_save_experiment, queue, name, description, version))
+    proc.start()
+
+    try:
+        result = queue.get(True, TIMEOUT)
+    except BaseException:
+        raise AutosubmitCritical(
+            "The database process exceeded the timeout limit {0}s. Your experiment {1} couldn't be stored in the database.".format(TIMEOUT, name))
+    finally:
+        proc.terminate()
+    return result
+
+def check_experiment_exists(name, error_on_inexistence=True):
+    """ 
+    Checks if exist an experiment with the given name. Anti-lock version.  
+
+    :param error_on_inexistence: if True, adds an error log if experiment does not exist
+    :type error_on_inexistence: bool
+    :param name: Experiment name
+    :type name: str
+    :return: If experiment exists returns true, if not returns false
+    :rtype: bool
+    """
+    queue = multiprocessing.Queue(1)
+    proc = multiprocessing.Process(target=fn_wrapper, args=(_check_experiment_exists, queue, name, error_on_inexistence))
+    proc.start()
+
+    try:
+        result = queue.get(True, TIMEOUT)
+    except BaseException:
+        raise AutosubmitCritical(
+            "The database process exceeded the timeout limit {0}s. Check if experiment {1} exists failed to complete.".format(TIMEOUT, name))
+    finally:
+        proc.terminate()
+    return result
+
+def update_experiment_descrip_version(name, description=None, version=None):
+    """
+    Updates the experiment's description and/or version. Anti-lock version.  
+
+    :param name: experiment name (expid)  
+    :rtype name: str  
+    :param description: experiment new description  
+    :rtype description: str  
+    :param version: experiment autosubmit version  
+    :rtype version: str  
+    :return: If description has been update, True; otherwise, False.  
+    :rtype: bool
+    """
+    queue = multiprocessing.Queue(1)
+    proc = multiprocessing.Process(target=fn_wrapper, args=(_update_experiment_descrip_version, queue, name, description, version))
+    proc.start()
+
+    try:
+        result = queue.get(True, TIMEOUT)
+    except BaseException:
+        raise AutosubmitCritical(
+            "The database process exceeded the timeout limit {0}s. Update experiment {1} version failed to complete.".format(TIMEOUT, name))
+    finally:
+        proc.terminate()
+    return result
+
+def get_autosubmit_version(expid):
+    """
+    Get the minimun autosubmit version needed for the experiment. Anti-lock version.  
+
+    :param expid: Experiment name
+    :type expid: str
+    :return: If experiment exists returns the autosubmit version for it, if not returns None
+    :rtype: str
+    """    
+    queue = multiprocessing.Queue(1)
+    proc = multiprocessing.Process(target=fn_wrapper, args=(_get_autosubmit_version, queue, expid))
+    proc.start()
+
+    try:
+        result = queue.get(True, TIMEOUT)
+    except BaseException:
+        raise AutosubmitCritical(
+            "The database process exceeded the timeout limit {0}s. Get experiment {1} version failed to complete.".format(TIMEOUT, expid))
+    finally:
+        proc.terminate()
+    return result
+
+def last_name_used(test=False, operational=False):
+    """
+    Gets last experiment identifier used. Anti-lock version.  
+
+    :param test: flag for test experiments
+    :type test: bool
+    :param operational: flag for operational experiments
+    :type test: bool
+    :return: last experiment identifier used, 'empty' if there is none
+    :rtype: str
+    """
+    queue = multiprocessing.Queue(1)
+    proc = multiprocessing.Process(target=fn_wrapper, args=(_last_name_used, queue, test, operational))
+    proc.start()
+
+    try:
+        result = queue.get(True, TIMEOUT)
+    except BaseException as e:
+        raise AutosubmitCritical(
+            "The database process exceeded the timeout limit {0}s. Get last named used failed to complete.".format(TIMEOUT),7000,str(e))
+    finally:
+        proc.terminate()
+    return result
+
+def delete_experiment(experiment_id):
+    """
+    Removes experiment from database. Anti-lock version.  
+
+    :param experiment_id: experiment identifier
+    :type experiment_id: str
+    :return: True if delete is succesful
+    :rtype: bool
+    """
+    queue = multiprocessing.Queue(1)
+    proc = multiprocessing.Process(target=fn_wrapper, args=(_delete_experiment, queue, experiment_id))
+    proc.start()
+
+    try:
+        result = queue.get(True, TIMEOUT)
+    except BaseException:
+        raise AutosubmitCritical(
+            "The database process exceeded the timeout limit {0}s. Delete experiment {1} failed to complete.".format(TIMEOUT, experiment_id))
+    finally:
+        proc.terminate()
+    return result
+
+def _save_experiment(name, description, version):
+    """
+    Stores experiment in database
+
+    :param version:
+    :type version: str
+    :param name: experiment's name
+    :type name: str
+    :param description: experiment's description
+    :type description: str
+    """
+    if not check_db():
+        return False
+    try:
+        (conn, cursor) = open_conn()
+    except DbException as e:
+        raise AutosubmitCritical(
+            "Could not establish a connection to database", 7001, str(e))
+    try:
+        cursor.execute('INSERT INTO experiment (name, description, autosubmit_version) VALUES (:name, :description, '
+                       ':version)',
+                       {'name': name, 'description': description, 'version': version})
+    except sqlite3.IntegrityError as e:
+        close_conn(conn, cursor)
+        raise AutosubmitCritical(
+            'Couldn''t register experiment', 7005, str(e))
+
+    conn.commit()
+    close_conn(conn, cursor)
+    return True
+
+
+def _check_experiment_exists(name, error_on_inexistence=True):
+    """
+    Checks if exist an experiment with the given name.
+
+    :param error_on_inexistence: if True, adds an error log if experiment does not exist
+    :type error_on_inexistence: bool
+    :param name: Experiment name
+    :type name: str
+    :return: If experiment exists returns true, if not returns false
+    :rtype: bool
+    """
+
+    if not check_db():
+        return False
+    try:
+        (conn, cursor) = open_conn()
+    except DbException as e:
+        raise AutosubmitCritical(
+            "Could not establish a connection to database", 7001, str(e))
+    conn.isolation_level = None
+
+    # SQLite always return a unicode object, but we can change this
+    # behaviour with the next sentence
+    conn.text_factory = str
+    cursor.execute(
+        'select name from experiment where name=:name', {'name': name})
+    row = cursor.fetchone()
+    close_conn(conn, cursor)
+    if row is None:
+        if error_on_inexistence:
+            raise AutosubmitCritical(
+                'The experiment name "{0}" does not exist yet!!!'.format(name), 7005)
+        if os.path.exists(os.path.join(BasicConfig.LOCAL_ROOT_DIR, name)):
+            try:
+                _save_experiment(name, 'No description', "3.14.0")
+            except  BaseException as e:
+                pass
+            return True
+        return False
+    return True
+
+def get_experiment_descrip(expid):
+    if not check_db():
+        return False
+    try:
+        (conn, cursor) = open_conn()
+    except DbException as e:
+        raise AutosubmitCritical(
+            "Could not establish a connection to the database.", 7001, str(e))
+    conn.isolation_level = None
+
+    # Changing default unicode
+    conn.text_factory = str
+    # get values
+    cursor.execute("select description from experiment where name='{0}'".format(expid))
+    return [row for row in cursor]
+
+
+def _update_experiment_descrip_version(name, description=None, version=None):
+    """
+    Updates the experiment's description and/or version
+
+    :param name: experiment name (expid)  
+    :rtype name: str  
+    :param description: experiment new description  
+    :rtype description: str  
+    :param version: experiment autosubmit version  
+    :rtype version: str  
+    :return: If description has been update, True; otherwise, False.  
+    :rtype: bool
+    """
+    if not check_db():
+        return False
+    try:
+        (conn, cursor) = open_conn()
+    except DbException as e:
+        raise AutosubmitCritical(
+            "Could not establish a connection to the database.", 7001, str(e))
+    conn.isolation_level = None
+
+    # Changing default unicode
+    conn.text_factory = str
+    # Conditional update
+    if description is not None and version is not None:
+        cursor.execute('update experiment set description=:description, autosubmit_version=:version where name=:name', {
+            'description': description, 'version': version, 'name': name})
+    elif description is not None and version is None:
+        cursor.execute('update experiment set description=:description where name=:name', {
+            'description': description, 'name': name})
+    elif version is not None and description is None:
+        cursor.execute('update experiment set autosubmit_version=:version where name=:name', {
+            'version': version, 'name': name})
+    else:
+        raise AutosubmitCritical(
+            "Not enough data to update {}.".format(name), 7005)
+    row = cursor.rowcount
+    close_conn(conn, cursor)
+    if row == 0:
+        raise AutosubmitCritical(
+            "Update on experiment {} failed.".format(name), 7005)
+        return False
+    return True
+
+
+def _get_autosubmit_version(expid):
+    """
+    Get the minimun autosubmit version needed for the experiment
+
+    :param expid: Experiment name
+    :type expid: str
+    :return: If experiment exists returns the autosubmit version for it, if not returns None
+    :rtype: str
+    """
+    if not check_db():
+        return False
+
+    try:
+        (conn, cursor) = open_conn()
+    except DbException as e:
+        raise AutosubmitCritical(
+            "Could not establish a connection to database", 7001, str(e))
+    conn.isolation_level = None
+
+    # SQLite always return a unicode object, but we can change this
+    # behaviour with the next sentence
+    conn.text_factory = str
+    cursor.execute('SELECT autosubmit_version FROM experiment WHERE name=:expid', {
+                   'expid': expid})
+    row = cursor.fetchone()
+    close_conn(conn, cursor)
+    if row is None:
+        raise AutosubmitCritical(
+            'The experiment "{0}" does not exist'.format(expid), 7005)
+    return row[0]
+
+
+
+
+
+
+
+
+
+
+def _last_name_used(test=False, operational=False):
+    """
+    Gets last experiment identifier used
+
+    :param test: flag for test experiments
+    :type test: bool
+    :param operational: flag for operational experiments
+    :type test: bool
+    :return: last experiment identifier used, 'empty' if there is none
+    :rtype: str
+    """    
+    if not check_db():
+        return ''
+    try:
+        (conn, cursor) = open_conn()
+    except DbException as e:
+        raise AutosubmitCritical(
+            "Could not establish a connection to database", 7001, str(e))
+    conn.text_factory = str
+    if test:
+        cursor.execute('SELECT name '
+                       'FROM experiment '
+                       'WHERE rowid=(SELECT max(rowid) FROM experiment WHERE name LIKE "t%" AND '
+                       'autosubmit_version IS NOT NULL AND '
+                       'NOT (autosubmit_version LIKE "%3.0.0b%"))')
+    elif operational:
+        cursor.execute('SELECT name '
+                       'FROM experiment '
+                       'WHERE rowid=(SELECT max(rowid) FROM experiment WHERE name LIKE "o%" AND '
+                       'autosubmit_version IS NOT NULL AND '
+                       'NOT (autosubmit_version LIKE "%3.0.0b%"))')
+    else:
+        cursor.execute('SELECT name '
+                       'FROM experiment '
+                       'WHERE rowid=(SELECT max(rowid) FROM experiment WHERE name NOT LIKE "t%" AND '
+                       'name NOT LIKE "o%" AND autosubmit_version IS NOT NULL AND '
+                       'NOT (autosubmit_version LIKE "%3.0.0b%"))')
+    row = cursor.fetchone()
+    close_conn(conn, cursor)
+    if row is None:
+        return 'empty'
+
+    # If starts by number (during 3.0 beta some jobs starting with numbers where created), returns empty.
+    try:
+        if row[0][0].isnumeric():
+            return 'empty'
+        else:
+            return row[0]
+    except ValueError:
+        return row[0]
+
+
+def _delete_experiment(experiment_id):
+    """
+    Removes experiment from database
+
+    :param experiment_id: experiment identifier
+    :type experiment_id: str
+    :return: True if delete is succesful
+    :rtype: bool
+    """
+    if not check_db():
+        return False
+    if not _check_experiment_exists(experiment_id, False): # Reference the no anti-lock version.
+        return True
+    try:
+        (conn, cursor) = open_conn()
+    except DbException as e:
+        raise AutosubmitCritical(
+            "Could not establish a connection to database", 7001, str(e))
+        return False
+    cursor.execute('DELETE FROM experiment '
+                   'WHERE name=:name', {'name': experiment_id})
+    row = cursor.fetchone()
+    if row is None:
+        Log.debug('The experiment {0} has been deleted!!!', experiment_id)
+    close_conn(conn, cursor)
+    return True
+
 
 def _update_database(version, cursor):
-
     Log.info("Autosubmit's database version is {0}. Current version is {1}. Updating...",
              version, CURRENT_DATABASE_VERSION)
     try:
@@ -460,10 +554,11 @@ def _update_database(version, cursor):
                                  'ALTER TABLE experiment ADD COLUMN autosubmit_version VARCHAR;'
                                  'UPDATE experiment SET autosubmit_version = "3.0.0b" '
                                  'WHERE autosubmit_version NOT NULL;')
-        cursor.execute('UPDATE db_version SET version={0};'.format(CURRENT_DATABASE_VERSION))
+        cursor.execute('UPDATE db_version SET version={0};'.format(
+            CURRENT_DATABASE_VERSION))
     except sqlite3.Error as e:
-        Log.critical('Can not update database: {0}', e)
-        return False
+        raise AutosubmitCritical(
+            'unable to update database version', 7001, str(e))
     Log.info("Update completed")
     return True
 
@@ -472,5 +567,6 @@ class DbException(Exception):
     """
     Exception class for database errors
     """
+
     def __init__(self, message):
         self.message = message
