@@ -104,7 +104,7 @@ class SgePlatform(ParamikoPlatform):
         jobs_xml = dom.getElementsByTagName("JB_job_number")
         return [int(element.firstChild.nodeValue) for element in jobs_xml]
 
-    def get_submit_cmd(self, job_script, job, export=""):
+    def get_submit_cmd(self, job_script, job, hold=False, export=""):
         if (export is None or export.lower() == "none") or len(export) == 0:
             export = ""
         else:
